angular
.module('ms.controller')
.controller('SearchCtrl', function($scope, $rootScope, $stateParams, $state, $ionicHistory, $ionicLoading, LocalService, ApiService) {
  $scope.data = {
    filterIndex: 1,
    keyword: '',
    searchResults: {
      news: [],
      journals: []
    },
    searchFinished: true,

    journalTotalPage: 2,
    journalPageNo: 1,
    newsTotalPage: 2,
    newsPageNo: 1,

    firstFilterChange: true
  };

  $rootScope.$on('FOCUS_CLICKED', function(event, data) {
    for (var index = 0; index < $scope.data.searchResults.journals.length; index++) {
      if ($scope.data.searchResults.journals[index].JID == data.journalID)
        break;
    }
    if (index < $scope.data.searchResults.journals.length) {
      if (data.addFlag) {
        $scope.data.searchResults.journals[index].focuses_count ++;
      } else {
        $scope.data.searchResults.journals[index].focuses_count --;
      }
    }
  });

  $scope.doRefresh = function() {
    init(true);
  };

  $scope.changeFilter = function(index) {
    if ($scope.data.filterIndex == index) {
      return;
    }
    $scope.data.filterIndex = index;
    if ($scope.data.firstFilterChange) {
      $scope.data.firstFilterChange = false;
      init(false);
    }
  }

  $scope.search = function() {
    $scope.data.searchResults.news = [];
    $scope.data.searchResults.journals = [];
    $scope.data.journalTotalPage = 2;
    $scope.data.journalPageNo = 1;
    $scope.data.newsTotalPage = 2;
    $scope.data.newsPageNo = 1;
    $scope.data.firstFilterChange = true;

    if ($scope.data.keyword)
      init(false);
  }

  $scope.loadMoreSearchJournals = function() {
    $scope.data.searchFinished = false;
    ApiService
      .loadSearchJournals({
        keyword: $scope.data.keyword,
        pageNo: $scope.data.journalPageNo + 1
      })
      .then(function(response) {
        $scope.data.journalTotalPage = response.data.totalPage;
        $scope.data.journalPageNo = response.data.pageNo;
        for (var i = 0; i < response.data.journals.length; i++) {
          $scope.data.searchResults.journals.push(response.data.journals[i]);
        }
      })
      .catch(function(response) {
      })
      .finally(function(response) {
        $ionicLoading.hide();
        $scope.data.searchFinished = true;
        $scope.$broadcast('scroll.infiniteScrollComplete');
      })
  }

  $scope.loadMoreSearchNews = function() {
    $scope.data.searchFinished = false;
    ApiService
      .loadSearchNews({
        keyword: $scope.data.keyword,
        pageNo: $scope.data.newsPageNo + 1
      })
      .then(function(response) {
        $scope.data.newsTotalPage = response.data.totalPage;
        $scope.data.newsPageNo = response.data.pageNo;
        for (var i = 0; i < response.data.news.length; i++) {
          $scope.data.searchResults.news.push(response.data.news[i]);
        }
      })
      .catch(function(response) {
      })
      .finally(function(response) {
        $ionicLoading.hide();
        $scope.data.searchFinished = true;
        $scope.$broadcast('scroll.infiniteScrollComplete');
      })
  }

  init(false);

  function init(isRefreshing) {
    if (! $scope.data.keyword) return;
    $scope.data.searchFinished = false;
    if ($scope.data.filterIndex == 1) { // 文章
      if (! isRefreshing) {
        $ionicLoading.show({
          template: '加载中...',
          showBackdrop: true,
        });
      }
      ApiService
        .loadSearchNews({
          keyword: $scope.data.keyword,
          pageNo: 1
        })
        .then(function(response) {
          $scope.data.newsTotalPage = response.data.totalPage;
          $scope.data.newsPageNo = response.data.pageNo;
          $scope.data.searchResults.news = response.data.news;
        })
        .catch(function(response) {
        })
        .finally(function(response) {
          if (! isRefreshing) {
            $ionicLoading.hide();
          } else {
            $scope.$broadcast('scroll.refreshComplete');
          }
          $scope.data.searchFinished = true;
        })
    } else { // 小刊
      if (! isRefreshing) {
        $ionicLoading.show({
          template: '加载中...',
          showBackdrop: true,
        });
      }
      ApiService
        .loadSearchJournals({
          keyword: $scope.data.keyword,
          pageNo: 1
        })
        .then(function(response) {
          $scope.data.journalTotalPage = response.data.totalPage;
          $scope.data.journalPageNo = response.data.pageNo;
          $scope.data.searchResults.journals = response.data.journals;
        })
        .catch(function(response) {
        })
        .finally(function(response) {
          if (! isRefreshing) {
            $ionicLoading.hide();
          } else {
            $scope.$broadcast('scroll.refreshComplete');
          }
          $scope.data.searchFinished = true;
        })
    }
  }

})
