angular
.module('ms.controller')
.controller('HomeCtrl', function($scope, $rootScope, $state, $location, $ionicHistory, $ionicLoading, $ionicScrollDelegate, LocalService, ApiService, AuthService, ModalService) {
  loadBannerAd(); //for ad
  $scope.data = {
    tabIndex: 0,
    topNews: [],
    userTopNews: [],

    totalPage: 1,
    pageNo: 1,

    userTotalPage: 1,
    userPageNo: 1,
    userJournalCount: 0
  }

  $scope.changeTab = function(index) {
    if ($scope.data.tabIndex == index) return;
    if (index == 1) {
      if (! AuthService.isAuthenticated()) {
        ModalService.loginModal.open($rootScope.login);
        return;
      }

      loadTopNewsOfFocusedJournals(false);
    }
    $scope.data.tabIndex = index;
  }

  $scope.doRefresh = function() {
    loadTopNews(true);
    loadBannerAd(); //for ad
  };

  $scope.loadMore = function() {
    ApiService
      .loadAllTopNews({
        pageNo: $scope.data.pageNo + 1,
        categoryID: 0 // 所有分类，（推荐）
      })
      .then(function(response) {
        $scope.data.totalPage = response.data.totalPage;
        $scope.data.pageNo = response.data.pageNo;

        for (var i = 0; i < response.data.news.length; i++) {
          var topNews = response.data.news[i];
          $scope.data.topNews.push(topNews);
        }
      })
      .catch(function(response) {
      })
      .finally(function() {
        $scope.$broadcast('scroll.infiniteScrollComplete');
      })
  }

  init();

  function init() {
    loadTopNews(false);
  }

  function loadTopNews(isRefreshing) {
    if (! isRefreshing) {
      $ionicLoading.show({
        template: '加载中...',
        showBackdrop: true,
      });
    }
    ApiService
      .loadAllTopNews({
        pageNo: 1,
        categoryID: 0
      })
      .then(function(response) {
        $scope.data.totalPage = response.data.totalPage;
        $scope.data.pageNo = response.data.pageNo;
        $scope.data.topNews = response.data.news;
      })
      .catch(function(error) {
      })
      .finally(function() {
        if (! isRefreshing) {
          $ionicLoading.hide();
        } else {
          $scope.$broadcast('scroll.refreshComplete');
        }
      });
  }


  $rootScope.$on('FOCUS_CLICKED', function(event, data) {
    if (data.addFlag) {
      $scope.data.journalCount++;
    } else {
      $scope.data.journalCount--;

      for (var index = $scope.data.userTopNews.length - 1; index >= 0; index--)
        if ($scope.data.userTopNews[index].journal.JID == data.journalID) {
          $scope.data.userTopNews[index].journal.focuses_count --;
          $scope.data.userTopNews.splice(index, 1);
        }
    }
  });

  $scope.doUserRefresh = function() {
    loadTopNewsOfFocusedJournals(true);
  };

  $scope.loadMoreUserJournals = function() {
    ApiService
      .loadTopNewsOfFocusedJournals({
        pageNo: $scope.data.userPageNo + 1
      })
      .then(function(response) {
        $scope.data.userPageNo = response.data.pageNo;
        $scope.data.userTotalPage = response.data.totalPage;
        $scope.data.userJournalCount = response.data.journalCount;
        for (var i = 0; i < response.data.topNews.length; i++) {
          $scope.data.userTopNews.push(response.data.topNews[i]);
        }
      })
      .catch(function(error) {
        if (error.status == 401) { // 已过期， 从新登陆
          AuthService
            .tokenExpired()
            .then(function() {
              ModalService.loginModal.open($rootScope.login);
            })
        }
      })
      .finally(function() {
        $scope.$broadcast('scroll.infiniteScrollComplete');
      })
  }

  function loadTopNewsOfFocusedJournals(isRefreshing) {
    $scope.data.loadingFinished = false;
    if (! isRefreshing) {
      $ionicLoading.show({
        template: '加载中...',
        showBackdrop: true,
      });
    }
    ApiService
      .loadTopNewsOfFocusedJournals({
        pageNo: 1
      })
      .then(function(response) {
        $scope.data.userTopNews = response.data.topNews;
        $scope.data.userPageNo = response.data.pageNo;
        $scope.data.userTotalCount = response.data.total;
        $scope.data.userTotalPage = response.data.totalPage;
        $scope.data.userJournalCount = response.data.journalCount;
      })
      .catch(function(error) {
        if (error.status == 401) { // 已过期， 从新登陆
          AuthService
            .tokenExpired()
            .then(function() {
              ModalService.loginModal.open($rootScope.login);
            })
        }
      })
      .finally(function() {
        $scope.data.loadingFinished = true;
        if (isRefreshing) {
          $scope.$broadcast('scroll.refreshComplete');
        } else {
          $ionicLoading.hide();
        }
      })
  }
})
